dew

package
v1.0.0-alpha.1760458278 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GetDataKeyArgs

type GetDataKeyArgs struct {
	DatakeyLength     string  `pulumi:"datakeyLength"`
	EncryptionContext *string `pulumi:"encryptionContext"`
	KeyId             string  `pulumi:"keyId"`
	Region            *string `pulumi:"region"`
}

A collection of arguments for invoking getDataKey.

type GetDataKeyOutputArgs

type GetDataKeyOutputArgs struct {
	DatakeyLength     pulumi.StringInput    `pulumi:"datakeyLength"`
	EncryptionContext pulumi.StringPtrInput `pulumi:"encryptionContext"`
	KeyId             pulumi.StringInput    `pulumi:"keyId"`
	Region            pulumi.StringPtrInput `pulumi:"region"`
}

A collection of arguments for invoking getDataKey.

func (GetDataKeyOutputArgs) ElementType

func (GetDataKeyOutputArgs) ElementType() reflect.Type

type GetDataKeyResult

type GetDataKeyResult struct {
	CipherText        string  `pulumi:"cipherText"`
	DatakeyLength     string  `pulumi:"datakeyLength"`
	EncryptionContext *string `pulumi:"encryptionContext"`
	// The provider-assigned unique ID for this managed resource.
	Id        string `pulumi:"id"`
	KeyId     string `pulumi:"keyId"`
	PlainText string `pulumi:"plainText"`
	Region    string `pulumi:"region"`
}

A collection of values returned by getDataKey.

func GetDataKey

func GetDataKey(ctx *pulumi.Context, args *GetDataKeyArgs, opts ...pulumi.InvokeOption) (*GetDataKeyResult, error)

type GetDataKeyResultOutput

type GetDataKeyResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getDataKey.

func (GetDataKeyResultOutput) CipherText

func (GetDataKeyResultOutput) DatakeyLength

func (o GetDataKeyResultOutput) DatakeyLength() pulumi.StringOutput

func (GetDataKeyResultOutput) ElementType

func (GetDataKeyResultOutput) ElementType() reflect.Type

func (GetDataKeyResultOutput) EncryptionContext

func (o GetDataKeyResultOutput) EncryptionContext() pulumi.StringPtrOutput

func (GetDataKeyResultOutput) Id

The provider-assigned unique ID for this managed resource.

func (GetDataKeyResultOutput) KeyId

func (GetDataKeyResultOutput) PlainText

func (GetDataKeyResultOutput) Region

func (GetDataKeyResultOutput) ToGetDataKeyResultOutput

func (o GetDataKeyResultOutput) ToGetDataKeyResultOutput() GetDataKeyResultOutput

func (GetDataKeyResultOutput) ToGetDataKeyResultOutputWithContext

func (o GetDataKeyResultOutput) ToGetDataKeyResultOutputWithContext(ctx context.Context) GetDataKeyResultOutput

type GetKeypairsArgs

type GetKeypairsArgs struct {
	Fingerprint *string `pulumi:"fingerprint"`
	IsManaged   *bool   `pulumi:"isManaged"`
	Name        *string `pulumi:"name"`
	PublicKey   *string `pulumi:"publicKey"`
	Region      *string `pulumi:"region"`
}

A collection of arguments for invoking getKeypairs.

type GetKeypairsKeypair

type GetKeypairsKeypair struct {
	Fingerprint string `pulumi:"fingerprint"`
	IsManaged   bool   `pulumi:"isManaged"`
	Name        string `pulumi:"name"`
	PublicKey   string `pulumi:"publicKey"`
	Scope       string `pulumi:"scope"`
}

type GetKeypairsKeypairArgs

type GetKeypairsKeypairArgs struct {
	Fingerprint pulumi.StringInput `pulumi:"fingerprint"`
	IsManaged   pulumi.BoolInput   `pulumi:"isManaged"`
	Name        pulumi.StringInput `pulumi:"name"`
	PublicKey   pulumi.StringInput `pulumi:"publicKey"`
	Scope       pulumi.StringInput `pulumi:"scope"`
}

func (GetKeypairsKeypairArgs) ElementType

func (GetKeypairsKeypairArgs) ElementType() reflect.Type

func (GetKeypairsKeypairArgs) ToGetKeypairsKeypairOutput

func (i GetKeypairsKeypairArgs) ToGetKeypairsKeypairOutput() GetKeypairsKeypairOutput

func (GetKeypairsKeypairArgs) ToGetKeypairsKeypairOutputWithContext

func (i GetKeypairsKeypairArgs) ToGetKeypairsKeypairOutputWithContext(ctx context.Context) GetKeypairsKeypairOutput

type GetKeypairsKeypairArray

type GetKeypairsKeypairArray []GetKeypairsKeypairInput

func (GetKeypairsKeypairArray) ElementType

func (GetKeypairsKeypairArray) ElementType() reflect.Type

func (GetKeypairsKeypairArray) ToGetKeypairsKeypairArrayOutput

func (i GetKeypairsKeypairArray) ToGetKeypairsKeypairArrayOutput() GetKeypairsKeypairArrayOutput

func (GetKeypairsKeypairArray) ToGetKeypairsKeypairArrayOutputWithContext

func (i GetKeypairsKeypairArray) ToGetKeypairsKeypairArrayOutputWithContext(ctx context.Context) GetKeypairsKeypairArrayOutput

type GetKeypairsKeypairArrayInput

type GetKeypairsKeypairArrayInput interface {
	pulumi.Input

	ToGetKeypairsKeypairArrayOutput() GetKeypairsKeypairArrayOutput
	ToGetKeypairsKeypairArrayOutputWithContext(context.Context) GetKeypairsKeypairArrayOutput
}

GetKeypairsKeypairArrayInput is an input type that accepts GetKeypairsKeypairArray and GetKeypairsKeypairArrayOutput values. You can construct a concrete instance of `GetKeypairsKeypairArrayInput` via:

GetKeypairsKeypairArray{ GetKeypairsKeypairArgs{...} }

type GetKeypairsKeypairArrayOutput

type GetKeypairsKeypairArrayOutput struct{ *pulumi.OutputState }

func (GetKeypairsKeypairArrayOutput) ElementType

func (GetKeypairsKeypairArrayOutput) Index

func (GetKeypairsKeypairArrayOutput) ToGetKeypairsKeypairArrayOutput

func (o GetKeypairsKeypairArrayOutput) ToGetKeypairsKeypairArrayOutput() GetKeypairsKeypairArrayOutput

func (GetKeypairsKeypairArrayOutput) ToGetKeypairsKeypairArrayOutputWithContext

func (o GetKeypairsKeypairArrayOutput) ToGetKeypairsKeypairArrayOutputWithContext(ctx context.Context) GetKeypairsKeypairArrayOutput

type GetKeypairsKeypairInput

type GetKeypairsKeypairInput interface {
	pulumi.Input

	ToGetKeypairsKeypairOutput() GetKeypairsKeypairOutput
	ToGetKeypairsKeypairOutputWithContext(context.Context) GetKeypairsKeypairOutput
}

GetKeypairsKeypairInput is an input type that accepts GetKeypairsKeypairArgs and GetKeypairsKeypairOutput values. You can construct a concrete instance of `GetKeypairsKeypairInput` via:

GetKeypairsKeypairArgs{...}

type GetKeypairsKeypairOutput

type GetKeypairsKeypairOutput struct{ *pulumi.OutputState }

func (GetKeypairsKeypairOutput) ElementType

func (GetKeypairsKeypairOutput) ElementType() reflect.Type

func (GetKeypairsKeypairOutput) Fingerprint

func (GetKeypairsKeypairOutput) IsManaged

func (GetKeypairsKeypairOutput) Name

func (GetKeypairsKeypairOutput) PublicKey

func (GetKeypairsKeypairOutput) Scope

func (GetKeypairsKeypairOutput) ToGetKeypairsKeypairOutput

func (o GetKeypairsKeypairOutput) ToGetKeypairsKeypairOutput() GetKeypairsKeypairOutput

func (GetKeypairsKeypairOutput) ToGetKeypairsKeypairOutputWithContext

func (o GetKeypairsKeypairOutput) ToGetKeypairsKeypairOutputWithContext(ctx context.Context) GetKeypairsKeypairOutput

type GetKeypairsOutputArgs

type GetKeypairsOutputArgs struct {
	Fingerprint pulumi.StringPtrInput `pulumi:"fingerprint"`
	IsManaged   pulumi.BoolPtrInput   `pulumi:"isManaged"`
	Name        pulumi.StringPtrInput `pulumi:"name"`
	PublicKey   pulumi.StringPtrInput `pulumi:"publicKey"`
	Region      pulumi.StringPtrInput `pulumi:"region"`
}

A collection of arguments for invoking getKeypairs.

func (GetKeypairsOutputArgs) ElementType

func (GetKeypairsOutputArgs) ElementType() reflect.Type

type GetKeypairsResult

type GetKeypairsResult struct {
	Fingerprint *string `pulumi:"fingerprint"`
	// The provider-assigned unique ID for this managed resource.
	Id        string               `pulumi:"id"`
	IsManaged *bool                `pulumi:"isManaged"`
	Keypairs  []GetKeypairsKeypair `pulumi:"keypairs"`
	Name      *string              `pulumi:"name"`
	PublicKey *string              `pulumi:"publicKey"`
	Region    *string              `pulumi:"region"`
}

A collection of values returned by getKeypairs.

func GetKeypairs

func GetKeypairs(ctx *pulumi.Context, args *GetKeypairsArgs, opts ...pulumi.InvokeOption) (*GetKeypairsResult, error)

type GetKeypairsResultOutput

type GetKeypairsResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getKeypairs.

func (GetKeypairsResultOutput) ElementType

func (GetKeypairsResultOutput) ElementType() reflect.Type

func (GetKeypairsResultOutput) Fingerprint

func (GetKeypairsResultOutput) Id

The provider-assigned unique ID for this managed resource.

func (GetKeypairsResultOutput) IsManaged

func (GetKeypairsResultOutput) Keypairs

func (GetKeypairsResultOutput) Name

func (GetKeypairsResultOutput) PublicKey

func (GetKeypairsResultOutput) Region

func (GetKeypairsResultOutput) ToGetKeypairsResultOutput

func (o GetKeypairsResultOutput) ToGetKeypairsResultOutput() GetKeypairsResultOutput

func (GetKeypairsResultOutput) ToGetKeypairsResultOutputWithContext

func (o GetKeypairsResultOutput) ToGetKeypairsResultOutputWithContext(ctx context.Context) GetKeypairsResultOutput

type Key

type Key struct {
	pulumi.CustomResourceState

	CreationDate          pulumi.StringOutput    `pulumi:"creationDate"`
	DefaultKeyFlag        pulumi.StringOutput    `pulumi:"defaultKeyFlag"`
	DomainId              pulumi.StringOutput    `pulumi:"domainId"`
	EnterpriseProjectId   pulumi.StringOutput    `pulumi:"enterpriseProjectId"`
	ExpirationTime        pulumi.StringOutput    `pulumi:"expirationTime"`
	IsEnabled             pulumi.BoolPtrOutput   `pulumi:"isEnabled"`
	KeyAlgorithm          pulumi.StringOutput    `pulumi:"keyAlgorithm"`
	KeyAlias              pulumi.StringOutput    `pulumi:"keyAlias"`
	KeyDescription        pulumi.StringPtrOutput `pulumi:"keyDescription"`
	KeyId                 pulumi.StringOutput    `pulumi:"keyId"`
	KeyState              pulumi.StringOutput    `pulumi:"keyState"`
	KeyUsage              pulumi.StringOutput    `pulumi:"keyUsage"`
	KeystoreId            pulumi.StringOutput    `pulumi:"keystoreId"`
	Origin                pulumi.StringOutput    `pulumi:"origin"`
	PendingDays           pulumi.StringPtrOutput `pulumi:"pendingDays"`
	Region                pulumi.StringOutput    `pulumi:"region"`
	RotationEnabled       pulumi.BoolPtrOutput   `pulumi:"rotationEnabled"`
	RotationInterval      pulumi.IntOutput       `pulumi:"rotationInterval"`
	RotationNumber        pulumi.IntOutput       `pulumi:"rotationNumber"`
	ScheduledDeletionDate pulumi.StringOutput    `pulumi:"scheduledDeletionDate"`
	Tags                  pulumi.StringMapOutput `pulumi:"tags"`
}

func GetKey

func GetKey(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *KeyState, opts ...pulumi.ResourceOption) (*Key, error)

GetKey gets an existing Key resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewKey

func NewKey(ctx *pulumi.Context,
	name string, args *KeyArgs, opts ...pulumi.ResourceOption) (*Key, error)

NewKey registers a new resource with the given unique name, arguments, and options.

func (*Key) ElementType

func (*Key) ElementType() reflect.Type

func (*Key) ToKeyOutput

func (i *Key) ToKeyOutput() KeyOutput

func (*Key) ToKeyOutputWithContext

func (i *Key) ToKeyOutputWithContext(ctx context.Context) KeyOutput

type KeyArgs

type KeyArgs struct {
	EnterpriseProjectId pulumi.StringPtrInput
	IsEnabled           pulumi.BoolPtrInput
	KeyAlgorithm        pulumi.StringPtrInput
	KeyAlias            pulumi.StringInput
	KeyDescription      pulumi.StringPtrInput
	KeyUsage            pulumi.StringPtrInput
	KeystoreId          pulumi.StringPtrInput
	Origin              pulumi.StringPtrInput
	PendingDays         pulumi.StringPtrInput
	Region              pulumi.StringPtrInput
	RotationEnabled     pulumi.BoolPtrInput
	RotationInterval    pulumi.IntPtrInput
	Tags                pulumi.StringMapInput
}

The set of arguments for constructing a Key resource.

func (KeyArgs) ElementType

func (KeyArgs) ElementType() reflect.Type

type KeyArray

type KeyArray []KeyInput

func (KeyArray) ElementType

func (KeyArray) ElementType() reflect.Type

func (KeyArray) ToKeyArrayOutput

func (i KeyArray) ToKeyArrayOutput() KeyArrayOutput

func (KeyArray) ToKeyArrayOutputWithContext

func (i KeyArray) ToKeyArrayOutputWithContext(ctx context.Context) KeyArrayOutput

type KeyArrayInput

type KeyArrayInput interface {
	pulumi.Input

	ToKeyArrayOutput() KeyArrayOutput
	ToKeyArrayOutputWithContext(context.Context) KeyArrayOutput
}

KeyArrayInput is an input type that accepts KeyArray and KeyArrayOutput values. You can construct a concrete instance of `KeyArrayInput` via:

KeyArray{ KeyArgs{...} }

type KeyArrayOutput

type KeyArrayOutput struct{ *pulumi.OutputState }

func (KeyArrayOutput) ElementType

func (KeyArrayOutput) ElementType() reflect.Type

func (KeyArrayOutput) Index

func (KeyArrayOutput) ToKeyArrayOutput

func (o KeyArrayOutput) ToKeyArrayOutput() KeyArrayOutput

func (KeyArrayOutput) ToKeyArrayOutputWithContext

func (o KeyArrayOutput) ToKeyArrayOutputWithContext(ctx context.Context) KeyArrayOutput

type KeyInput

type KeyInput interface {
	pulumi.Input

	ToKeyOutput() KeyOutput
	ToKeyOutputWithContext(ctx context.Context) KeyOutput
}

type KeyMap

type KeyMap map[string]KeyInput

func (KeyMap) ElementType

func (KeyMap) ElementType() reflect.Type

func (KeyMap) ToKeyMapOutput

func (i KeyMap) ToKeyMapOutput() KeyMapOutput

func (KeyMap) ToKeyMapOutputWithContext

func (i KeyMap) ToKeyMapOutputWithContext(ctx context.Context) KeyMapOutput

type KeyMapInput

type KeyMapInput interface {
	pulumi.Input

	ToKeyMapOutput() KeyMapOutput
	ToKeyMapOutputWithContext(context.Context) KeyMapOutput
}

KeyMapInput is an input type that accepts KeyMap and KeyMapOutput values. You can construct a concrete instance of `KeyMapInput` via:

KeyMap{ "key": KeyArgs{...} }

type KeyMapOutput

type KeyMapOutput struct{ *pulumi.OutputState }

func (KeyMapOutput) ElementType

func (KeyMapOutput) ElementType() reflect.Type

func (KeyMapOutput) MapIndex

func (o KeyMapOutput) MapIndex(k pulumi.StringInput) KeyOutput

func (KeyMapOutput) ToKeyMapOutput

func (o KeyMapOutput) ToKeyMapOutput() KeyMapOutput

func (KeyMapOutput) ToKeyMapOutputWithContext

func (o KeyMapOutput) ToKeyMapOutputWithContext(ctx context.Context) KeyMapOutput

type KeyOutput

type KeyOutput struct{ *pulumi.OutputState }

func (KeyOutput) CreationDate

func (o KeyOutput) CreationDate() pulumi.StringOutput

func (KeyOutput) DefaultKeyFlag

func (o KeyOutput) DefaultKeyFlag() pulumi.StringOutput

func (KeyOutput) DomainId

func (o KeyOutput) DomainId() pulumi.StringOutput

func (KeyOutput) ElementType

func (KeyOutput) ElementType() reflect.Type

func (KeyOutput) EnterpriseProjectId

func (o KeyOutput) EnterpriseProjectId() pulumi.StringOutput

func (KeyOutput) ExpirationTime

func (o KeyOutput) ExpirationTime() pulumi.StringOutput

func (KeyOutput) IsEnabled

func (o KeyOutput) IsEnabled() pulumi.BoolPtrOutput

func (KeyOutput) KeyAlgorithm

func (o KeyOutput) KeyAlgorithm() pulumi.StringOutput

func (KeyOutput) KeyAlias

func (o KeyOutput) KeyAlias() pulumi.StringOutput

func (KeyOutput) KeyDescription

func (o KeyOutput) KeyDescription() pulumi.StringPtrOutput

func (KeyOutput) KeyId

func (o KeyOutput) KeyId() pulumi.StringOutput

func (KeyOutput) KeyState

func (o KeyOutput) KeyState() pulumi.StringOutput

func (KeyOutput) KeyUsage

func (o KeyOutput) KeyUsage() pulumi.StringOutput

func (KeyOutput) KeystoreId

func (o KeyOutput) KeystoreId() pulumi.StringOutput

func (KeyOutput) Origin

func (o KeyOutput) Origin() pulumi.StringOutput

func (KeyOutput) PendingDays

func (o KeyOutput) PendingDays() pulumi.StringPtrOutput

func (KeyOutput) Region

func (o KeyOutput) Region() pulumi.StringOutput

func (KeyOutput) RotationEnabled

func (o KeyOutput) RotationEnabled() pulumi.BoolPtrOutput

func (KeyOutput) RotationInterval

func (o KeyOutput) RotationInterval() pulumi.IntOutput

func (KeyOutput) RotationNumber

func (o KeyOutput) RotationNumber() pulumi.IntOutput

func (KeyOutput) ScheduledDeletionDate

func (o KeyOutput) ScheduledDeletionDate() pulumi.StringOutput

func (KeyOutput) Tags

func (o KeyOutput) Tags() pulumi.StringMapOutput

func (KeyOutput) ToKeyOutput

func (o KeyOutput) ToKeyOutput() KeyOutput

func (KeyOutput) ToKeyOutputWithContext

func (o KeyOutput) ToKeyOutputWithContext(ctx context.Context) KeyOutput

type KeyState

type KeyState struct {
	CreationDate          pulumi.StringPtrInput
	DefaultKeyFlag        pulumi.StringPtrInput
	DomainId              pulumi.StringPtrInput
	EnterpriseProjectId   pulumi.StringPtrInput
	ExpirationTime        pulumi.StringPtrInput
	IsEnabled             pulumi.BoolPtrInput
	KeyAlgorithm          pulumi.StringPtrInput
	KeyAlias              pulumi.StringPtrInput
	KeyDescription        pulumi.StringPtrInput
	KeyId                 pulumi.StringPtrInput
	KeyState              pulumi.StringPtrInput
	KeyUsage              pulumi.StringPtrInput
	KeystoreId            pulumi.StringPtrInput
	Origin                pulumi.StringPtrInput
	PendingDays           pulumi.StringPtrInput
	Region                pulumi.StringPtrInput
	RotationEnabled       pulumi.BoolPtrInput
	RotationInterval      pulumi.IntPtrInput
	RotationNumber        pulumi.IntPtrInput
	ScheduledDeletionDate pulumi.StringPtrInput
	Tags                  pulumi.StringMapInput
}

func (KeyState) ElementType

func (KeyState) ElementType() reflect.Type

type Keypair

type Keypair struct {
	pulumi.CustomResourceState

	CreatedAt      pulumi.StringOutput    `pulumi:"createdAt"`
	Description    pulumi.StringPtrOutput `pulumi:"description"`
	EncryptionType pulumi.StringOutput    `pulumi:"encryptionType"`
	Fingerprint    pulumi.StringOutput    `pulumi:"fingerprint"`
	IsManaged      pulumi.BoolOutput      `pulumi:"isManaged"`
	KeyFile        pulumi.StringOutput    `pulumi:"keyFile"`
	KmsKeyId       pulumi.StringPtrOutput `pulumi:"kmsKeyId"`
	KmsKeyName     pulumi.StringPtrOutput `pulumi:"kmsKeyName"`
	Name           pulumi.StringOutput    `pulumi:"name"`
	PrivateKey     pulumi.StringPtrOutput `pulumi:"privateKey"`
	PublicKey      pulumi.StringOutput    `pulumi:"publicKey"`
	Region         pulumi.StringOutput    `pulumi:"region"`
	Scope          pulumi.StringOutput    `pulumi:"scope"`
	UserId         pulumi.StringOutput    `pulumi:"userId"`
}

func GetKeypair

func GetKeypair(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *KeypairState, opts ...pulumi.ResourceOption) (*Keypair, error)

GetKeypair gets an existing Keypair resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewKeypair

func NewKeypair(ctx *pulumi.Context,
	name string, args *KeypairArgs, opts ...pulumi.ResourceOption) (*Keypair, error)

NewKeypair registers a new resource with the given unique name, arguments, and options.

func (*Keypair) ElementType

func (*Keypair) ElementType() reflect.Type

func (*Keypair) ToKeypairOutput

func (i *Keypair) ToKeypairOutput() KeypairOutput

func (*Keypair) ToKeypairOutputWithContext

func (i *Keypair) ToKeypairOutputWithContext(ctx context.Context) KeypairOutput

type KeypairArgs

type KeypairArgs struct {
	Description    pulumi.StringPtrInput
	EncryptionType pulumi.StringPtrInput
	KeyFile        pulumi.StringPtrInput
	KmsKeyId       pulumi.StringPtrInput
	KmsKeyName     pulumi.StringPtrInput
	Name           pulumi.StringPtrInput
	PrivateKey     pulumi.StringPtrInput
	PublicKey      pulumi.StringPtrInput
	Region         pulumi.StringPtrInput
	Scope          pulumi.StringPtrInput
	UserId         pulumi.StringPtrInput
}

The set of arguments for constructing a Keypair resource.

func (KeypairArgs) ElementType

func (KeypairArgs) ElementType() reflect.Type

type KeypairArray

type KeypairArray []KeypairInput

func (KeypairArray) ElementType

func (KeypairArray) ElementType() reflect.Type

func (KeypairArray) ToKeypairArrayOutput

func (i KeypairArray) ToKeypairArrayOutput() KeypairArrayOutput

func (KeypairArray) ToKeypairArrayOutputWithContext

func (i KeypairArray) ToKeypairArrayOutputWithContext(ctx context.Context) KeypairArrayOutput

type KeypairArrayInput

type KeypairArrayInput interface {
	pulumi.Input

	ToKeypairArrayOutput() KeypairArrayOutput
	ToKeypairArrayOutputWithContext(context.Context) KeypairArrayOutput
}

KeypairArrayInput is an input type that accepts KeypairArray and KeypairArrayOutput values. You can construct a concrete instance of `KeypairArrayInput` via:

KeypairArray{ KeypairArgs{...} }

type KeypairArrayOutput

type KeypairArrayOutput struct{ *pulumi.OutputState }

func (KeypairArrayOutput) ElementType

func (KeypairArrayOutput) ElementType() reflect.Type

func (KeypairArrayOutput) Index

func (KeypairArrayOutput) ToKeypairArrayOutput

func (o KeypairArrayOutput) ToKeypairArrayOutput() KeypairArrayOutput

func (KeypairArrayOutput) ToKeypairArrayOutputWithContext

func (o KeypairArrayOutput) ToKeypairArrayOutputWithContext(ctx context.Context) KeypairArrayOutput

type KeypairInput

type KeypairInput interface {
	pulumi.Input

	ToKeypairOutput() KeypairOutput
	ToKeypairOutputWithContext(ctx context.Context) KeypairOutput
}

type KeypairMap

type KeypairMap map[string]KeypairInput

func (KeypairMap) ElementType

func (KeypairMap) ElementType() reflect.Type

func (KeypairMap) ToKeypairMapOutput

func (i KeypairMap) ToKeypairMapOutput() KeypairMapOutput

func (KeypairMap) ToKeypairMapOutputWithContext

func (i KeypairMap) ToKeypairMapOutputWithContext(ctx context.Context) KeypairMapOutput

type KeypairMapInput

type KeypairMapInput interface {
	pulumi.Input

	ToKeypairMapOutput() KeypairMapOutput
	ToKeypairMapOutputWithContext(context.Context) KeypairMapOutput
}

KeypairMapInput is an input type that accepts KeypairMap and KeypairMapOutput values. You can construct a concrete instance of `KeypairMapInput` via:

KeypairMap{ "key": KeypairArgs{...} }

type KeypairMapOutput

type KeypairMapOutput struct{ *pulumi.OutputState }

func (KeypairMapOutput) ElementType

func (KeypairMapOutput) ElementType() reflect.Type

func (KeypairMapOutput) MapIndex

func (KeypairMapOutput) ToKeypairMapOutput

func (o KeypairMapOutput) ToKeypairMapOutput() KeypairMapOutput

func (KeypairMapOutput) ToKeypairMapOutputWithContext

func (o KeypairMapOutput) ToKeypairMapOutputWithContext(ctx context.Context) KeypairMapOutput

type KeypairOutput

type KeypairOutput struct{ *pulumi.OutputState }

func (KeypairOutput) CreatedAt

func (o KeypairOutput) CreatedAt() pulumi.StringOutput

func (KeypairOutput) Description

func (o KeypairOutput) Description() pulumi.StringPtrOutput

func (KeypairOutput) ElementType

func (KeypairOutput) ElementType() reflect.Type

func (KeypairOutput) EncryptionType

func (o KeypairOutput) EncryptionType() pulumi.StringOutput

func (KeypairOutput) Fingerprint

func (o KeypairOutput) Fingerprint() pulumi.StringOutput

func (KeypairOutput) IsManaged

func (o KeypairOutput) IsManaged() pulumi.BoolOutput

func (KeypairOutput) KeyFile

func (o KeypairOutput) KeyFile() pulumi.StringOutput

func (KeypairOutput) KmsKeyId

func (o KeypairOutput) KmsKeyId() pulumi.StringPtrOutput

func (KeypairOutput) KmsKeyName

func (o KeypairOutput) KmsKeyName() pulumi.StringPtrOutput

func (KeypairOutput) Name

func (KeypairOutput) PrivateKey

func (o KeypairOutput) PrivateKey() pulumi.StringPtrOutput

func (KeypairOutput) PublicKey

func (o KeypairOutput) PublicKey() pulumi.StringOutput

func (KeypairOutput) Region

func (o KeypairOutput) Region() pulumi.StringOutput

func (KeypairOutput) Scope

func (o KeypairOutput) Scope() pulumi.StringOutput

func (KeypairOutput) ToKeypairOutput

func (o KeypairOutput) ToKeypairOutput() KeypairOutput

func (KeypairOutput) ToKeypairOutputWithContext

func (o KeypairOutput) ToKeypairOutputWithContext(ctx context.Context) KeypairOutput

func (KeypairOutput) UserId

func (o KeypairOutput) UserId() pulumi.StringOutput

type KeypairState

type KeypairState struct {
	CreatedAt      pulumi.StringPtrInput
	Description    pulumi.StringPtrInput
	EncryptionType pulumi.StringPtrInput
	Fingerprint    pulumi.StringPtrInput
	IsManaged      pulumi.BoolPtrInput
	KeyFile        pulumi.StringPtrInput
	KmsKeyId       pulumi.StringPtrInput
	KmsKeyName     pulumi.StringPtrInput
	Name           pulumi.StringPtrInput
	PrivateKey     pulumi.StringPtrInput
	PublicKey      pulumi.StringPtrInput
	Region         pulumi.StringPtrInput
	Scope          pulumi.StringPtrInput
	UserId         pulumi.StringPtrInput
}

func (KeypairState) ElementType

func (KeypairState) ElementType() reflect.Type

type LookupKeyArgs

type LookupKeyArgs struct {
	DefaultKeyFlag      *string `pulumi:"defaultKeyFlag"`
	DomainId            *string `pulumi:"domainId"`
	EnterpriseProjectId *string `pulumi:"enterpriseProjectId"`
	KeyAlias            *string `pulumi:"keyAlias"`
	KeyDescription      *string `pulumi:"keyDescription"`
	KeyId               *string `pulumi:"keyId"`
	KeyState            *string `pulumi:"keyState"`
	Region              *string `pulumi:"region"`
}

A collection of arguments for invoking getKey.

type LookupKeyOutputArgs

type LookupKeyOutputArgs struct {
	DefaultKeyFlag      pulumi.StringPtrInput `pulumi:"defaultKeyFlag"`
	DomainId            pulumi.StringPtrInput `pulumi:"domainId"`
	EnterpriseProjectId pulumi.StringPtrInput `pulumi:"enterpriseProjectId"`
	KeyAlias            pulumi.StringPtrInput `pulumi:"keyAlias"`
	KeyDescription      pulumi.StringPtrInput `pulumi:"keyDescription"`
	KeyId               pulumi.StringPtrInput `pulumi:"keyId"`
	KeyState            pulumi.StringPtrInput `pulumi:"keyState"`
	Region              pulumi.StringPtrInput `pulumi:"region"`
}

A collection of arguments for invoking getKey.

func (LookupKeyOutputArgs) ElementType

func (LookupKeyOutputArgs) ElementType() reflect.Type

type LookupKeyResult

type LookupKeyResult struct {
	CreationDate        string `pulumi:"creationDate"`
	DefaultKeyFlag      string `pulumi:"defaultKeyFlag"`
	DomainId            string `pulumi:"domainId"`
	EnterpriseProjectId string `pulumi:"enterpriseProjectId"`
	ExpirationTime      string `pulumi:"expirationTime"`
	// The provider-assigned unique ID for this managed resource.
	Id                    string            `pulumi:"id"`
	KeyAlias              string            `pulumi:"keyAlias"`
	KeyDescription        string            `pulumi:"keyDescription"`
	KeyId                 string            `pulumi:"keyId"`
	KeyState              string            `pulumi:"keyState"`
	Region                string            `pulumi:"region"`
	RotationEnabled       bool              `pulumi:"rotationEnabled"`
	RotationInterval      int               `pulumi:"rotationInterval"`
	RotationNumber        int               `pulumi:"rotationNumber"`
	ScheduledDeletionDate string            `pulumi:"scheduledDeletionDate"`
	Tags                  map[string]string `pulumi:"tags"`
}

A collection of values returned by getKey.

func LookupKey

func LookupKey(ctx *pulumi.Context, args *LookupKeyArgs, opts ...pulumi.InvokeOption) (*LookupKeyResult, error)

type LookupKeyResultOutput

type LookupKeyResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getKey.

func (LookupKeyResultOutput) CreationDate

func (o LookupKeyResultOutput) CreationDate() pulumi.StringOutput

func (LookupKeyResultOutput) DefaultKeyFlag

func (o LookupKeyResultOutput) DefaultKeyFlag() pulumi.StringOutput

func (LookupKeyResultOutput) DomainId

func (LookupKeyResultOutput) ElementType

func (LookupKeyResultOutput) ElementType() reflect.Type

func (LookupKeyResultOutput) EnterpriseProjectId

func (o LookupKeyResultOutput) EnterpriseProjectId() pulumi.StringOutput

func (LookupKeyResultOutput) ExpirationTime

func (o LookupKeyResultOutput) ExpirationTime() pulumi.StringOutput

func (LookupKeyResultOutput) Id

The provider-assigned unique ID for this managed resource.

func (LookupKeyResultOutput) KeyAlias

func (LookupKeyResultOutput) KeyDescription

func (o LookupKeyResultOutput) KeyDescription() pulumi.StringOutput

func (LookupKeyResultOutput) KeyId

func (LookupKeyResultOutput) KeyState

func (LookupKeyResultOutput) Region

func (LookupKeyResultOutput) RotationEnabled

func (o LookupKeyResultOutput) RotationEnabled() pulumi.BoolOutput

func (LookupKeyResultOutput) RotationInterval

func (o LookupKeyResultOutput) RotationInterval() pulumi.IntOutput

func (LookupKeyResultOutput) RotationNumber

func (o LookupKeyResultOutput) RotationNumber() pulumi.IntOutput

func (LookupKeyResultOutput) ScheduledDeletionDate

func (o LookupKeyResultOutput) ScheduledDeletionDate() pulumi.StringOutput

func (LookupKeyResultOutput) Tags

func (LookupKeyResultOutput) ToLookupKeyResultOutput

func (o LookupKeyResultOutput) ToLookupKeyResultOutput() LookupKeyResultOutput

func (LookupKeyResultOutput) ToLookupKeyResultOutputWithContext

func (o LookupKeyResultOutput) ToLookupKeyResultOutputWithContext(ctx context.Context) LookupKeyResultOutput

Jump to