dws

package
v1.0.0-alpha.1760458278 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cluster

type Cluster struct {
	pulumi.CustomResourceState

	// The availability zone in which to create the cluster instance.
	AvailabilityZone pulumi.StringOutput `pulumi:"availabilityZone"`
	// The creation time of the cluster.
	Created pulumi.StringOutput `pulumi:"created"`
	// The description of the cluster.
	Description pulumi.StringPtrOutput `pulumi:"description"`
	// Dedicated storage pool ID.
	DssPoolId pulumi.StringOutput `pulumi:"dssPoolId"`
	// The ID of the ELB load balancer.
	ElbId pulumi.StringPtrOutput `pulumi:"elbId"`
	// The ELB information bound to the cluster.
	Elbs ClusterElbArrayOutput `pulumi:"elbs"`
	// Private network connection information about the cluster.
	Endpoints ClusterEndpointArrayOutput `pulumi:"endpoints"`
	// The enterprise project ID.
	EnterpriseProjectId pulumi.StringOutput `pulumi:"enterpriseProjectId"`
	// Whether to automatically execute snapshot when shrinking the number of nodes.
	ForceBackup pulumi.BoolPtrOutput `pulumi:"forceBackup"`
	// The number of latest manual snapshots that need to be retained when deleting the cluster.
	KeepLastManualSnapshot pulumi.IntPtrOutput `pulumi:"keepLastManualSnapshot"`
	// The KMS key ID.
	KmsKeyId pulumi.StringOutput `pulumi:"kmsKeyId"`
	// Whether to enable logical cluster.
	LogicalClusterEnable pulumi.BoolPtrOutput `pulumi:"logicalClusterEnable"`
	// Whether to enable LTS.
	LtsEnable pulumi.BoolPtrOutput `pulumi:"ltsEnable"`
	// Cluster maintenance window.
	MaintainWindows ClusterMaintainWindowArrayOutput `pulumi:"maintainWindows"`
	// The cluster name.
	Name pulumi.StringOutput `pulumi:"name"`
	// The subnet ID.
	NetworkId pulumi.StringOutput `pulumi:"networkId"`
	// The flavor of the cluster.
	NodeType pulumi.StringOutput `pulumi:"nodeType"`
	// schema: Required
	NumberOfCn pulumi.IntPtrOutput `pulumi:"numberOfCn"`
	// Number of nodes in a cluster.
	NumberOfNode pulumi.IntOutput `pulumi:"numberOfNode"`
	// Service port of a cluster (8000 to 10000). The default value is 8000.
	Port pulumi.IntPtrOutput `pulumi:"port"`
	// List of private network IP addresses.
	PrivateIps pulumi.StringArrayOutput `pulumi:"privateIps"`
	// Public network connection information about the cluster.
	PublicEndpoints ClusterPublicEndpointArrayOutput `pulumi:"publicEndpoints"`
	PublicIp        ClusterPublicIpOutput            `pulumi:"publicIp"`
	RecentEvent     pulumi.IntOutput                 `pulumi:"recentEvent"`
	Region          pulumi.StringOutput              `pulumi:"region"`
	// The security group ID.
	SecurityGroupId pulumi.StringOutput `pulumi:"securityGroupId"`
	// The cluster status.
	Status pulumi.StringOutput `pulumi:"status"`
	// Sub-status of clusters in the AVAILABLE state.
	SubStatus pulumi.StringOutput    `pulumi:"subStatus"`
	Tags      pulumi.StringMapOutput `pulumi:"tags"`
	// Cluster management task.
	TaskStatus pulumi.StringOutput `pulumi:"taskStatus"`
	// The updated time of the cluster.
	Updated pulumi.StringOutput `pulumi:"updated"`
	// Administrator username for logging in to a data warehouse cluster.
	UserName pulumi.StringOutput `pulumi:"userName"`
	// Administrator password for logging in to a data warehouse cluster.
	UserPwd pulumi.StringOutput `pulumi:"userPwd"`
	// schema: Required
	Version pulumi.StringOutput `pulumi:"version"`
	Volume  ClusterVolumeOutput `pulumi:"volume"`
	// The VPC ID.
	VpcId pulumi.StringOutput `pulumi:"vpcId"`
}

func GetCluster

func GetCluster(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *ClusterState, opts ...pulumi.ResourceOption) (*Cluster, error)

GetCluster gets an existing Cluster resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewCluster

func NewCluster(ctx *pulumi.Context,
	name string, args *ClusterArgs, opts ...pulumi.ResourceOption) (*Cluster, error)

NewCluster registers a new resource with the given unique name, arguments, and options.

func (*Cluster) ElementType

func (*Cluster) ElementType() reflect.Type

func (*Cluster) ToClusterOutput

func (i *Cluster) ToClusterOutput() ClusterOutput

func (*Cluster) ToClusterOutputWithContext

func (i *Cluster) ToClusterOutputWithContext(ctx context.Context) ClusterOutput

type ClusterArgs

type ClusterArgs struct {
	// The availability zone in which to create the cluster instance.
	AvailabilityZone pulumi.StringInput
	// The description of the cluster.
	Description pulumi.StringPtrInput
	// Dedicated storage pool ID.
	DssPoolId pulumi.StringPtrInput
	// The ID of the ELB load balancer.
	ElbId pulumi.StringPtrInput
	// The enterprise project ID.
	EnterpriseProjectId pulumi.StringPtrInput
	// Whether to automatically execute snapshot when shrinking the number of nodes.
	ForceBackup pulumi.BoolPtrInput
	// The number of latest manual snapshots that need to be retained when deleting the cluster.
	KeepLastManualSnapshot pulumi.IntPtrInput
	// The KMS key ID.
	KmsKeyId pulumi.StringPtrInput
	// Whether to enable logical cluster.
	LogicalClusterEnable pulumi.BoolPtrInput
	// Whether to enable LTS.
	LtsEnable pulumi.BoolPtrInput
	// The cluster name.
	Name pulumi.StringPtrInput
	// The subnet ID.
	NetworkId pulumi.StringInput
	// The flavor of the cluster.
	NodeType pulumi.StringInput
	// schema: Required
	NumberOfCn pulumi.IntPtrInput
	// Number of nodes in a cluster.
	NumberOfNode pulumi.IntInput
	// Service port of a cluster (8000 to 10000). The default value is 8000.
	Port     pulumi.IntPtrInput
	PublicIp ClusterPublicIpPtrInput
	Region   pulumi.StringPtrInput
	// The security group ID.
	SecurityGroupId pulumi.StringInput
	Tags            pulumi.StringMapInput
	// Administrator username for logging in to a data warehouse cluster.
	UserName pulumi.StringInput
	// Administrator password for logging in to a data warehouse cluster.
	UserPwd pulumi.StringInput
	// schema: Required
	Version pulumi.StringPtrInput
	Volume  ClusterVolumePtrInput
	// The VPC ID.
	VpcId pulumi.StringInput
}

The set of arguments for constructing a Cluster resource.

func (ClusterArgs) ElementType

func (ClusterArgs) ElementType() reflect.Type

type ClusterArray

type ClusterArray []ClusterInput

func (ClusterArray) ElementType

func (ClusterArray) ElementType() reflect.Type

func (ClusterArray) ToClusterArrayOutput

func (i ClusterArray) ToClusterArrayOutput() ClusterArrayOutput

func (ClusterArray) ToClusterArrayOutputWithContext

func (i ClusterArray) ToClusterArrayOutputWithContext(ctx context.Context) ClusterArrayOutput

type ClusterArrayInput

type ClusterArrayInput interface {
	pulumi.Input

	ToClusterArrayOutput() ClusterArrayOutput
	ToClusterArrayOutputWithContext(context.Context) ClusterArrayOutput
}

ClusterArrayInput is an input type that accepts ClusterArray and ClusterArrayOutput values. You can construct a concrete instance of `ClusterArrayInput` via:

ClusterArray{ ClusterArgs{...} }

type ClusterArrayOutput

type ClusterArrayOutput struct{ *pulumi.OutputState }

func (ClusterArrayOutput) ElementType

func (ClusterArrayOutput) ElementType() reflect.Type

func (ClusterArrayOutput) Index

func (ClusterArrayOutput) ToClusterArrayOutput

func (o ClusterArrayOutput) ToClusterArrayOutput() ClusterArrayOutput

func (ClusterArrayOutput) ToClusterArrayOutputWithContext

func (o ClusterArrayOutput) ToClusterArrayOutputWithContext(ctx context.Context) ClusterArrayOutput

type ClusterElb

type ClusterElb struct {
	// The ID of the ELB load balancer.
	Id *string `pulumi:"id"`
	// The name of the ELB load balancer.
	Name *string `pulumi:"name"`
	// The private endpoint of the ELB load balancer.
	PrivateEndpoint *string `pulumi:"privateEndpoint"`
	// The private IP address of the ELB load balancer.
	PrivateIp *string `pulumi:"privateIp"`
	// The IPv6 address of the ELB load balancer.
	PrivateIpV6 *string `pulumi:"privateIpV6"`
	// The public IP address of the ELB load balancer.
	PublicIp *string `pulumi:"publicIp"`
	// The ID of VPC to which the ELB load balancer belongs.
	VpcId *string `pulumi:"vpcId"`
}

type ClusterElbArgs

type ClusterElbArgs struct {
	// The ID of the ELB load balancer.
	Id pulumi.StringPtrInput `pulumi:"id"`
	// The name of the ELB load balancer.
	Name pulumi.StringPtrInput `pulumi:"name"`
	// The private endpoint of the ELB load balancer.
	PrivateEndpoint pulumi.StringPtrInput `pulumi:"privateEndpoint"`
	// The private IP address of the ELB load balancer.
	PrivateIp pulumi.StringPtrInput `pulumi:"privateIp"`
	// The IPv6 address of the ELB load balancer.
	PrivateIpV6 pulumi.StringPtrInput `pulumi:"privateIpV6"`
	// The public IP address of the ELB load balancer.
	PublicIp pulumi.StringPtrInput `pulumi:"publicIp"`
	// The ID of VPC to which the ELB load balancer belongs.
	VpcId pulumi.StringPtrInput `pulumi:"vpcId"`
}

func (ClusterElbArgs) ElementType

func (ClusterElbArgs) ElementType() reflect.Type

func (ClusterElbArgs) ToClusterElbOutput

func (i ClusterElbArgs) ToClusterElbOutput() ClusterElbOutput

func (ClusterElbArgs) ToClusterElbOutputWithContext

func (i ClusterElbArgs) ToClusterElbOutputWithContext(ctx context.Context) ClusterElbOutput

type ClusterElbArray

type ClusterElbArray []ClusterElbInput

func (ClusterElbArray) ElementType

func (ClusterElbArray) ElementType() reflect.Type

func (ClusterElbArray) ToClusterElbArrayOutput

func (i ClusterElbArray) ToClusterElbArrayOutput() ClusterElbArrayOutput

func (ClusterElbArray) ToClusterElbArrayOutputWithContext

func (i ClusterElbArray) ToClusterElbArrayOutputWithContext(ctx context.Context) ClusterElbArrayOutput

type ClusterElbArrayInput

type ClusterElbArrayInput interface {
	pulumi.Input

	ToClusterElbArrayOutput() ClusterElbArrayOutput
	ToClusterElbArrayOutputWithContext(context.Context) ClusterElbArrayOutput
}

ClusterElbArrayInput is an input type that accepts ClusterElbArray and ClusterElbArrayOutput values. You can construct a concrete instance of `ClusterElbArrayInput` via:

ClusterElbArray{ ClusterElbArgs{...} }

type ClusterElbArrayOutput

type ClusterElbArrayOutput struct{ *pulumi.OutputState }

func (ClusterElbArrayOutput) ElementType

func (ClusterElbArrayOutput) ElementType() reflect.Type

func (ClusterElbArrayOutput) Index

func (ClusterElbArrayOutput) ToClusterElbArrayOutput

func (o ClusterElbArrayOutput) ToClusterElbArrayOutput() ClusterElbArrayOutput

func (ClusterElbArrayOutput) ToClusterElbArrayOutputWithContext

func (o ClusterElbArrayOutput) ToClusterElbArrayOutputWithContext(ctx context.Context) ClusterElbArrayOutput

type ClusterElbInput

type ClusterElbInput interface {
	pulumi.Input

	ToClusterElbOutput() ClusterElbOutput
	ToClusterElbOutputWithContext(context.Context) ClusterElbOutput
}

ClusterElbInput is an input type that accepts ClusterElbArgs and ClusterElbOutput values. You can construct a concrete instance of `ClusterElbInput` via:

ClusterElbArgs{...}

type ClusterElbOutput

type ClusterElbOutput struct{ *pulumi.OutputState }

func (ClusterElbOutput) ElementType

func (ClusterElbOutput) ElementType() reflect.Type

func (ClusterElbOutput) Id

The ID of the ELB load balancer.

func (ClusterElbOutput) Name

The name of the ELB load balancer.

func (ClusterElbOutput) PrivateEndpoint

func (o ClusterElbOutput) PrivateEndpoint() pulumi.StringPtrOutput

The private endpoint of the ELB load balancer.

func (ClusterElbOutput) PrivateIp

func (o ClusterElbOutput) PrivateIp() pulumi.StringPtrOutput

The private IP address of the ELB load balancer.

func (ClusterElbOutput) PrivateIpV6

func (o ClusterElbOutput) PrivateIpV6() pulumi.StringPtrOutput

The IPv6 address of the ELB load balancer.

func (ClusterElbOutput) PublicIp

The public IP address of the ELB load balancer.

func (ClusterElbOutput) ToClusterElbOutput

func (o ClusterElbOutput) ToClusterElbOutput() ClusterElbOutput

func (ClusterElbOutput) ToClusterElbOutputWithContext

func (o ClusterElbOutput) ToClusterElbOutputWithContext(ctx context.Context) ClusterElbOutput

func (ClusterElbOutput) VpcId

The ID of VPC to which the ELB load balancer belongs.

type ClusterEndpoint

type ClusterEndpoint struct {
	// Private network connection information.
	ConnectInfo *string `pulumi:"connectInfo"`
	// JDBC URL. Format: jdbc:postgresql://<connect_info>/<YOUR_DATABASE_NAME>
	JdbcUrl *string `pulumi:"jdbcUrl"`
}

type ClusterEndpointArgs

type ClusterEndpointArgs struct {
	// Private network connection information.
	ConnectInfo pulumi.StringPtrInput `pulumi:"connectInfo"`
	// JDBC URL. Format: jdbc:postgresql://<connect_info>/<YOUR_DATABASE_NAME>
	JdbcUrl pulumi.StringPtrInput `pulumi:"jdbcUrl"`
}

func (ClusterEndpointArgs) ElementType

func (ClusterEndpointArgs) ElementType() reflect.Type

func (ClusterEndpointArgs) ToClusterEndpointOutput

func (i ClusterEndpointArgs) ToClusterEndpointOutput() ClusterEndpointOutput

func (ClusterEndpointArgs) ToClusterEndpointOutputWithContext

func (i ClusterEndpointArgs) ToClusterEndpointOutputWithContext(ctx context.Context) ClusterEndpointOutput

type ClusterEndpointArray

type ClusterEndpointArray []ClusterEndpointInput

func (ClusterEndpointArray) ElementType

func (ClusterEndpointArray) ElementType() reflect.Type

func (ClusterEndpointArray) ToClusterEndpointArrayOutput

func (i ClusterEndpointArray) ToClusterEndpointArrayOutput() ClusterEndpointArrayOutput

func (ClusterEndpointArray) ToClusterEndpointArrayOutputWithContext

func (i ClusterEndpointArray) ToClusterEndpointArrayOutputWithContext(ctx context.Context) ClusterEndpointArrayOutput

type ClusterEndpointArrayInput

type ClusterEndpointArrayInput interface {
	pulumi.Input

	ToClusterEndpointArrayOutput() ClusterEndpointArrayOutput
	ToClusterEndpointArrayOutputWithContext(context.Context) ClusterEndpointArrayOutput
}

ClusterEndpointArrayInput is an input type that accepts ClusterEndpointArray and ClusterEndpointArrayOutput values. You can construct a concrete instance of `ClusterEndpointArrayInput` via:

ClusterEndpointArray{ ClusterEndpointArgs{...} }

type ClusterEndpointArrayOutput

type ClusterEndpointArrayOutput struct{ *pulumi.OutputState }

func (ClusterEndpointArrayOutput) ElementType

func (ClusterEndpointArrayOutput) ElementType() reflect.Type

func (ClusterEndpointArrayOutput) Index

func (ClusterEndpointArrayOutput) ToClusterEndpointArrayOutput

func (o ClusterEndpointArrayOutput) ToClusterEndpointArrayOutput() ClusterEndpointArrayOutput

func (ClusterEndpointArrayOutput) ToClusterEndpointArrayOutputWithContext

func (o ClusterEndpointArrayOutput) ToClusterEndpointArrayOutputWithContext(ctx context.Context) ClusterEndpointArrayOutput

type ClusterEndpointInput

type ClusterEndpointInput interface {
	pulumi.Input

	ToClusterEndpointOutput() ClusterEndpointOutput
	ToClusterEndpointOutputWithContext(context.Context) ClusterEndpointOutput
}

ClusterEndpointInput is an input type that accepts ClusterEndpointArgs and ClusterEndpointOutput values. You can construct a concrete instance of `ClusterEndpointInput` via:

ClusterEndpointArgs{...}

type ClusterEndpointOutput

type ClusterEndpointOutput struct{ *pulumi.OutputState }

func (ClusterEndpointOutput) ConnectInfo

Private network connection information.

func (ClusterEndpointOutput) ElementType

func (ClusterEndpointOutput) ElementType() reflect.Type

func (ClusterEndpointOutput) JdbcUrl

JDBC URL. Format: jdbc:postgresql://<connect_info>/<YOUR_DATABASE_NAME>

func (ClusterEndpointOutput) ToClusterEndpointOutput

func (o ClusterEndpointOutput) ToClusterEndpointOutput() ClusterEndpointOutput

func (ClusterEndpointOutput) ToClusterEndpointOutputWithContext

func (o ClusterEndpointOutput) ToClusterEndpointOutputWithContext(ctx context.Context) ClusterEndpointOutput

type ClusterInput

type ClusterInput interface {
	pulumi.Input

	ToClusterOutput() ClusterOutput
	ToClusterOutputWithContext(ctx context.Context) ClusterOutput
}

type ClusterMaintainWindow

type ClusterMaintainWindow struct {
	// Maintenance time in each week in the unit of day.
	Day *string `pulumi:"day"`
	// Maintenance end time in HH:mm format. The time zone is GMT+0.
	EndTime *string `pulumi:"endTime"`
	// Maintenance start time in HH:mm format. The time zone is GMT+0.
	StartTime *string `pulumi:"startTime"`
}

type ClusterMaintainWindowArgs

type ClusterMaintainWindowArgs struct {
	// Maintenance time in each week in the unit of day.
	Day pulumi.StringPtrInput `pulumi:"day"`
	// Maintenance end time in HH:mm format. The time zone is GMT+0.
	EndTime pulumi.StringPtrInput `pulumi:"endTime"`
	// Maintenance start time in HH:mm format. The time zone is GMT+0.
	StartTime pulumi.StringPtrInput `pulumi:"startTime"`
}

func (ClusterMaintainWindowArgs) ElementType

func (ClusterMaintainWindowArgs) ElementType() reflect.Type

func (ClusterMaintainWindowArgs) ToClusterMaintainWindowOutput

func (i ClusterMaintainWindowArgs) ToClusterMaintainWindowOutput() ClusterMaintainWindowOutput

func (ClusterMaintainWindowArgs) ToClusterMaintainWindowOutputWithContext

func (i ClusterMaintainWindowArgs) ToClusterMaintainWindowOutputWithContext(ctx context.Context) ClusterMaintainWindowOutput

type ClusterMaintainWindowArray

type ClusterMaintainWindowArray []ClusterMaintainWindowInput

func (ClusterMaintainWindowArray) ElementType

func (ClusterMaintainWindowArray) ElementType() reflect.Type

func (ClusterMaintainWindowArray) ToClusterMaintainWindowArrayOutput

func (i ClusterMaintainWindowArray) ToClusterMaintainWindowArrayOutput() ClusterMaintainWindowArrayOutput

func (ClusterMaintainWindowArray) ToClusterMaintainWindowArrayOutputWithContext

func (i ClusterMaintainWindowArray) ToClusterMaintainWindowArrayOutputWithContext(ctx context.Context) ClusterMaintainWindowArrayOutput

type ClusterMaintainWindowArrayInput

type ClusterMaintainWindowArrayInput interface {
	pulumi.Input

	ToClusterMaintainWindowArrayOutput() ClusterMaintainWindowArrayOutput
	ToClusterMaintainWindowArrayOutputWithContext(context.Context) ClusterMaintainWindowArrayOutput
}

ClusterMaintainWindowArrayInput is an input type that accepts ClusterMaintainWindowArray and ClusterMaintainWindowArrayOutput values. You can construct a concrete instance of `ClusterMaintainWindowArrayInput` via:

ClusterMaintainWindowArray{ ClusterMaintainWindowArgs{...} }

type ClusterMaintainWindowArrayOutput

type ClusterMaintainWindowArrayOutput struct{ *pulumi.OutputState }

func (ClusterMaintainWindowArrayOutput) ElementType

func (ClusterMaintainWindowArrayOutput) Index

func (ClusterMaintainWindowArrayOutput) ToClusterMaintainWindowArrayOutput

func (o ClusterMaintainWindowArrayOutput) ToClusterMaintainWindowArrayOutput() ClusterMaintainWindowArrayOutput

func (ClusterMaintainWindowArrayOutput) ToClusterMaintainWindowArrayOutputWithContext

func (o ClusterMaintainWindowArrayOutput) ToClusterMaintainWindowArrayOutputWithContext(ctx context.Context) ClusterMaintainWindowArrayOutput

type ClusterMaintainWindowInput

type ClusterMaintainWindowInput interface {
	pulumi.Input

	ToClusterMaintainWindowOutput() ClusterMaintainWindowOutput
	ToClusterMaintainWindowOutputWithContext(context.Context) ClusterMaintainWindowOutput
}

ClusterMaintainWindowInput is an input type that accepts ClusterMaintainWindowArgs and ClusterMaintainWindowOutput values. You can construct a concrete instance of `ClusterMaintainWindowInput` via:

ClusterMaintainWindowArgs{...}

type ClusterMaintainWindowOutput

type ClusterMaintainWindowOutput struct{ *pulumi.OutputState }

func (ClusterMaintainWindowOutput) Day

Maintenance time in each week in the unit of day.

func (ClusterMaintainWindowOutput) ElementType

func (ClusterMaintainWindowOutput) EndTime

Maintenance end time in HH:mm format. The time zone is GMT+0.

func (ClusterMaintainWindowOutput) StartTime

Maintenance start time in HH:mm format. The time zone is GMT+0.

func (ClusterMaintainWindowOutput) ToClusterMaintainWindowOutput

func (o ClusterMaintainWindowOutput) ToClusterMaintainWindowOutput() ClusterMaintainWindowOutput

func (ClusterMaintainWindowOutput) ToClusterMaintainWindowOutputWithContext

func (o ClusterMaintainWindowOutput) ToClusterMaintainWindowOutputWithContext(ctx context.Context) ClusterMaintainWindowOutput

type ClusterMap

type ClusterMap map[string]ClusterInput

func (ClusterMap) ElementType

func (ClusterMap) ElementType() reflect.Type

func (ClusterMap) ToClusterMapOutput

func (i ClusterMap) ToClusterMapOutput() ClusterMapOutput

func (ClusterMap) ToClusterMapOutputWithContext

func (i ClusterMap) ToClusterMapOutputWithContext(ctx context.Context) ClusterMapOutput

type ClusterMapInput

type ClusterMapInput interface {
	pulumi.Input

	ToClusterMapOutput() ClusterMapOutput
	ToClusterMapOutputWithContext(context.Context) ClusterMapOutput
}

ClusterMapInput is an input type that accepts ClusterMap and ClusterMapOutput values. You can construct a concrete instance of `ClusterMapInput` via:

ClusterMap{ "key": ClusterArgs{...} }

type ClusterMapOutput

type ClusterMapOutput struct{ *pulumi.OutputState }

func (ClusterMapOutput) ElementType

func (ClusterMapOutput) ElementType() reflect.Type

func (ClusterMapOutput) MapIndex

func (ClusterMapOutput) ToClusterMapOutput

func (o ClusterMapOutput) ToClusterMapOutput() ClusterMapOutput

func (ClusterMapOutput) ToClusterMapOutputWithContext

func (o ClusterMapOutput) ToClusterMapOutputWithContext(ctx context.Context) ClusterMapOutput

type ClusterOutput

type ClusterOutput struct{ *pulumi.OutputState }

func (ClusterOutput) AvailabilityZone

func (o ClusterOutput) AvailabilityZone() pulumi.StringOutput

The availability zone in which to create the cluster instance.

func (ClusterOutput) Created

func (o ClusterOutput) Created() pulumi.StringOutput

The creation time of the cluster.

func (ClusterOutput) Description

func (o ClusterOutput) Description() pulumi.StringPtrOutput

The description of the cluster.

func (ClusterOutput) DssPoolId

func (o ClusterOutput) DssPoolId() pulumi.StringOutput

Dedicated storage pool ID.

func (ClusterOutput) ElbId

The ID of the ELB load balancer.

func (ClusterOutput) Elbs

The ELB information bound to the cluster.

func (ClusterOutput) ElementType

func (ClusterOutput) ElementType() reflect.Type

func (ClusterOutput) Endpoints

Private network connection information about the cluster.

func (ClusterOutput) EnterpriseProjectId

func (o ClusterOutput) EnterpriseProjectId() pulumi.StringOutput

The enterprise project ID.

func (ClusterOutput) ForceBackup

func (o ClusterOutput) ForceBackup() pulumi.BoolPtrOutput

Whether to automatically execute snapshot when shrinking the number of nodes.

func (ClusterOutput) KeepLastManualSnapshot

func (o ClusterOutput) KeepLastManualSnapshot() pulumi.IntPtrOutput

The number of latest manual snapshots that need to be retained when deleting the cluster.

func (ClusterOutput) KmsKeyId

func (o ClusterOutput) KmsKeyId() pulumi.StringOutput

The KMS key ID.

func (ClusterOutput) LogicalClusterEnable

func (o ClusterOutput) LogicalClusterEnable() pulumi.BoolPtrOutput

Whether to enable logical cluster.

func (ClusterOutput) LtsEnable

func (o ClusterOutput) LtsEnable() pulumi.BoolPtrOutput

Whether to enable LTS.

func (ClusterOutput) MaintainWindows

func (o ClusterOutput) MaintainWindows() ClusterMaintainWindowArrayOutput

Cluster maintenance window.

func (ClusterOutput) Name

The cluster name.

func (ClusterOutput) NetworkId

func (o ClusterOutput) NetworkId() pulumi.StringOutput

The subnet ID.

func (ClusterOutput) NodeType

func (o ClusterOutput) NodeType() pulumi.StringOutput

The flavor of the cluster.

func (ClusterOutput) NumberOfCn

func (o ClusterOutput) NumberOfCn() pulumi.IntPtrOutput

schema: Required

func (ClusterOutput) NumberOfNode

func (o ClusterOutput) NumberOfNode() pulumi.IntOutput

Number of nodes in a cluster.

func (ClusterOutput) Port

Service port of a cluster (8000 to 10000). The default value is 8000.

func (ClusterOutput) PrivateIps

func (o ClusterOutput) PrivateIps() pulumi.StringArrayOutput

List of private network IP addresses.

func (ClusterOutput) PublicEndpoints

func (o ClusterOutput) PublicEndpoints() ClusterPublicEndpointArrayOutput

Public network connection information about the cluster.

func (ClusterOutput) PublicIp

func (o ClusterOutput) PublicIp() ClusterPublicIpOutput

func (ClusterOutput) RecentEvent

func (o ClusterOutput) RecentEvent() pulumi.IntOutput

func (ClusterOutput) Region

func (o ClusterOutput) Region() pulumi.StringOutput

func (ClusterOutput) SecurityGroupId

func (o ClusterOutput) SecurityGroupId() pulumi.StringOutput

The security group ID.

func (ClusterOutput) Status

func (o ClusterOutput) Status() pulumi.StringOutput

The cluster status.

func (ClusterOutput) SubStatus

func (o ClusterOutput) SubStatus() pulumi.StringOutput

Sub-status of clusters in the AVAILABLE state.

func (ClusterOutput) Tags

func (ClusterOutput) TaskStatus

func (o ClusterOutput) TaskStatus() pulumi.StringOutput

Cluster management task.

func (ClusterOutput) ToClusterOutput

func (o ClusterOutput) ToClusterOutput() ClusterOutput

func (ClusterOutput) ToClusterOutputWithContext

func (o ClusterOutput) ToClusterOutputWithContext(ctx context.Context) ClusterOutput

func (ClusterOutput) Updated

func (o ClusterOutput) Updated() pulumi.StringOutput

The updated time of the cluster.

func (ClusterOutput) UserName

func (o ClusterOutput) UserName() pulumi.StringOutput

Administrator username for logging in to a data warehouse cluster.

func (ClusterOutput) UserPwd

func (o ClusterOutput) UserPwd() pulumi.StringOutput

Administrator password for logging in to a data warehouse cluster.

func (ClusterOutput) Version

func (o ClusterOutput) Version() pulumi.StringOutput

schema: Required

func (ClusterOutput) Volume

func (ClusterOutput) VpcId

func (o ClusterOutput) VpcId() pulumi.StringOutput

The VPC ID.

type ClusterPublicEndpoint

type ClusterPublicEndpoint struct {
	// JDBC URL. Format: jdbc:postgresql://<public_connect_info>/<YOUR_DATABASE_NAME>
	JdbcUrl *string `pulumi:"jdbcUrl"`
	// Public network connection information.
	PublicConnectInfo *string `pulumi:"publicConnectInfo"`
}

type ClusterPublicEndpointArgs

type ClusterPublicEndpointArgs struct {
	// JDBC URL. Format: jdbc:postgresql://<public_connect_info>/<YOUR_DATABASE_NAME>
	JdbcUrl pulumi.StringPtrInput `pulumi:"jdbcUrl"`
	// Public network connection information.
	PublicConnectInfo pulumi.StringPtrInput `pulumi:"publicConnectInfo"`
}

func (ClusterPublicEndpointArgs) ElementType

func (ClusterPublicEndpointArgs) ElementType() reflect.Type

func (ClusterPublicEndpointArgs) ToClusterPublicEndpointOutput

func (i ClusterPublicEndpointArgs) ToClusterPublicEndpointOutput() ClusterPublicEndpointOutput

func (ClusterPublicEndpointArgs) ToClusterPublicEndpointOutputWithContext

func (i ClusterPublicEndpointArgs) ToClusterPublicEndpointOutputWithContext(ctx context.Context) ClusterPublicEndpointOutput

type ClusterPublicEndpointArray

type ClusterPublicEndpointArray []ClusterPublicEndpointInput

func (ClusterPublicEndpointArray) ElementType

func (ClusterPublicEndpointArray) ElementType() reflect.Type

func (ClusterPublicEndpointArray) ToClusterPublicEndpointArrayOutput

func (i ClusterPublicEndpointArray) ToClusterPublicEndpointArrayOutput() ClusterPublicEndpointArrayOutput

func (ClusterPublicEndpointArray) ToClusterPublicEndpointArrayOutputWithContext

func (i ClusterPublicEndpointArray) ToClusterPublicEndpointArrayOutputWithContext(ctx context.Context) ClusterPublicEndpointArrayOutput

type ClusterPublicEndpointArrayInput

type ClusterPublicEndpointArrayInput interface {
	pulumi.Input

	ToClusterPublicEndpointArrayOutput() ClusterPublicEndpointArrayOutput
	ToClusterPublicEndpointArrayOutputWithContext(context.Context) ClusterPublicEndpointArrayOutput
}

ClusterPublicEndpointArrayInput is an input type that accepts ClusterPublicEndpointArray and ClusterPublicEndpointArrayOutput values. You can construct a concrete instance of `ClusterPublicEndpointArrayInput` via:

ClusterPublicEndpointArray{ ClusterPublicEndpointArgs{...} }

type ClusterPublicEndpointArrayOutput

type ClusterPublicEndpointArrayOutput struct{ *pulumi.OutputState }

func (ClusterPublicEndpointArrayOutput) ElementType

func (ClusterPublicEndpointArrayOutput) Index

func (ClusterPublicEndpointArrayOutput) ToClusterPublicEndpointArrayOutput

func (o ClusterPublicEndpointArrayOutput) ToClusterPublicEndpointArrayOutput() ClusterPublicEndpointArrayOutput

func (ClusterPublicEndpointArrayOutput) ToClusterPublicEndpointArrayOutputWithContext

func (o ClusterPublicEndpointArrayOutput) ToClusterPublicEndpointArrayOutputWithContext(ctx context.Context) ClusterPublicEndpointArrayOutput

type ClusterPublicEndpointInput

type ClusterPublicEndpointInput interface {
	pulumi.Input

	ToClusterPublicEndpointOutput() ClusterPublicEndpointOutput
	ToClusterPublicEndpointOutputWithContext(context.Context) ClusterPublicEndpointOutput
}

ClusterPublicEndpointInput is an input type that accepts ClusterPublicEndpointArgs and ClusterPublicEndpointOutput values. You can construct a concrete instance of `ClusterPublicEndpointInput` via:

ClusterPublicEndpointArgs{...}

type ClusterPublicEndpointOutput

type ClusterPublicEndpointOutput struct{ *pulumi.OutputState }

func (ClusterPublicEndpointOutput) ElementType

func (ClusterPublicEndpointOutput) JdbcUrl

JDBC URL. Format: jdbc:postgresql://<public_connect_info>/<YOUR_DATABASE_NAME>

func (ClusterPublicEndpointOutput) PublicConnectInfo

func (o ClusterPublicEndpointOutput) PublicConnectInfo() pulumi.StringPtrOutput

Public network connection information.

func (ClusterPublicEndpointOutput) ToClusterPublicEndpointOutput

func (o ClusterPublicEndpointOutput) ToClusterPublicEndpointOutput() ClusterPublicEndpointOutput

func (ClusterPublicEndpointOutput) ToClusterPublicEndpointOutputWithContext

func (o ClusterPublicEndpointOutput) ToClusterPublicEndpointOutputWithContext(ctx context.Context) ClusterPublicEndpointOutput

type ClusterPublicIp

type ClusterPublicIp struct {
	// The EIP ID.
	EipId *string `pulumi:"eipId"`
	// The bind type of public IP.
	PublicBindType *string `pulumi:"publicBindType"`
}

type ClusterPublicIpArgs

type ClusterPublicIpArgs struct {
	// The EIP ID.
	EipId pulumi.StringPtrInput `pulumi:"eipId"`
	// The bind type of public IP.
	PublicBindType pulumi.StringPtrInput `pulumi:"publicBindType"`
}

func (ClusterPublicIpArgs) ElementType

func (ClusterPublicIpArgs) ElementType() reflect.Type

func (ClusterPublicIpArgs) ToClusterPublicIpOutput

func (i ClusterPublicIpArgs) ToClusterPublicIpOutput() ClusterPublicIpOutput

func (ClusterPublicIpArgs) ToClusterPublicIpOutputWithContext

func (i ClusterPublicIpArgs) ToClusterPublicIpOutputWithContext(ctx context.Context) ClusterPublicIpOutput

func (ClusterPublicIpArgs) ToClusterPublicIpPtrOutput

func (i ClusterPublicIpArgs) ToClusterPublicIpPtrOutput() ClusterPublicIpPtrOutput

func (ClusterPublicIpArgs) ToClusterPublicIpPtrOutputWithContext

func (i ClusterPublicIpArgs) ToClusterPublicIpPtrOutputWithContext(ctx context.Context) ClusterPublicIpPtrOutput

type ClusterPublicIpInput

type ClusterPublicIpInput interface {
	pulumi.Input

	ToClusterPublicIpOutput() ClusterPublicIpOutput
	ToClusterPublicIpOutputWithContext(context.Context) ClusterPublicIpOutput
}

ClusterPublicIpInput is an input type that accepts ClusterPublicIpArgs and ClusterPublicIpOutput values. You can construct a concrete instance of `ClusterPublicIpInput` via:

ClusterPublicIpArgs{...}

type ClusterPublicIpOutput

type ClusterPublicIpOutput struct{ *pulumi.OutputState }

func (ClusterPublicIpOutput) EipId

The EIP ID.

func (ClusterPublicIpOutput) ElementType

func (ClusterPublicIpOutput) ElementType() reflect.Type

func (ClusterPublicIpOutput) PublicBindType

func (o ClusterPublicIpOutput) PublicBindType() pulumi.StringPtrOutput

The bind type of public IP.

func (ClusterPublicIpOutput) ToClusterPublicIpOutput

func (o ClusterPublicIpOutput) ToClusterPublicIpOutput() ClusterPublicIpOutput

func (ClusterPublicIpOutput) ToClusterPublicIpOutputWithContext

func (o ClusterPublicIpOutput) ToClusterPublicIpOutputWithContext(ctx context.Context) ClusterPublicIpOutput

func (ClusterPublicIpOutput) ToClusterPublicIpPtrOutput

func (o ClusterPublicIpOutput) ToClusterPublicIpPtrOutput() ClusterPublicIpPtrOutput

func (ClusterPublicIpOutput) ToClusterPublicIpPtrOutputWithContext

func (o ClusterPublicIpOutput) ToClusterPublicIpPtrOutputWithContext(ctx context.Context) ClusterPublicIpPtrOutput

type ClusterPublicIpPtrInput

type ClusterPublicIpPtrInput interface {
	pulumi.Input

	ToClusterPublicIpPtrOutput() ClusterPublicIpPtrOutput
	ToClusterPublicIpPtrOutputWithContext(context.Context) ClusterPublicIpPtrOutput
}

ClusterPublicIpPtrInput is an input type that accepts ClusterPublicIpArgs, ClusterPublicIpPtr and ClusterPublicIpPtrOutput values. You can construct a concrete instance of `ClusterPublicIpPtrInput` via:

        ClusterPublicIpArgs{...}

or:

        nil

type ClusterPublicIpPtrOutput

type ClusterPublicIpPtrOutput struct{ *pulumi.OutputState }

func (ClusterPublicIpPtrOutput) EipId

The EIP ID.

func (ClusterPublicIpPtrOutput) Elem

func (ClusterPublicIpPtrOutput) ElementType

func (ClusterPublicIpPtrOutput) ElementType() reflect.Type

func (ClusterPublicIpPtrOutput) PublicBindType

func (o ClusterPublicIpPtrOutput) PublicBindType() pulumi.StringPtrOutput

The bind type of public IP.

func (ClusterPublicIpPtrOutput) ToClusterPublicIpPtrOutput

func (o ClusterPublicIpPtrOutput) ToClusterPublicIpPtrOutput() ClusterPublicIpPtrOutput

func (ClusterPublicIpPtrOutput) ToClusterPublicIpPtrOutputWithContext

func (o ClusterPublicIpPtrOutput) ToClusterPublicIpPtrOutputWithContext(ctx context.Context) ClusterPublicIpPtrOutput

type ClusterState

type ClusterState struct {
	// The availability zone in which to create the cluster instance.
	AvailabilityZone pulumi.StringPtrInput
	// The creation time of the cluster.
	Created pulumi.StringPtrInput
	// The description of the cluster.
	Description pulumi.StringPtrInput
	// Dedicated storage pool ID.
	DssPoolId pulumi.StringPtrInput
	// The ID of the ELB load balancer.
	ElbId pulumi.StringPtrInput
	// The ELB information bound to the cluster.
	Elbs ClusterElbArrayInput
	// Private network connection information about the cluster.
	Endpoints ClusterEndpointArrayInput
	// The enterprise project ID.
	EnterpriseProjectId pulumi.StringPtrInput
	// Whether to automatically execute snapshot when shrinking the number of nodes.
	ForceBackup pulumi.BoolPtrInput
	// The number of latest manual snapshots that need to be retained when deleting the cluster.
	KeepLastManualSnapshot pulumi.IntPtrInput
	// The KMS key ID.
	KmsKeyId pulumi.StringPtrInput
	// Whether to enable logical cluster.
	LogicalClusterEnable pulumi.BoolPtrInput
	// Whether to enable LTS.
	LtsEnable pulumi.BoolPtrInput
	// Cluster maintenance window.
	MaintainWindows ClusterMaintainWindowArrayInput
	// The cluster name.
	Name pulumi.StringPtrInput
	// The subnet ID.
	NetworkId pulumi.StringPtrInput
	// The flavor of the cluster.
	NodeType pulumi.StringPtrInput
	// schema: Required
	NumberOfCn pulumi.IntPtrInput
	// Number of nodes in a cluster.
	NumberOfNode pulumi.IntPtrInput
	// Service port of a cluster (8000 to 10000). The default value is 8000.
	Port pulumi.IntPtrInput
	// List of private network IP addresses.
	PrivateIps pulumi.StringArrayInput
	// Public network connection information about the cluster.
	PublicEndpoints ClusterPublicEndpointArrayInput
	PublicIp        ClusterPublicIpPtrInput
	RecentEvent     pulumi.IntPtrInput
	Region          pulumi.StringPtrInput
	// The security group ID.
	SecurityGroupId pulumi.StringPtrInput
	// The cluster status.
	Status pulumi.StringPtrInput
	// Sub-status of clusters in the AVAILABLE state.
	SubStatus pulumi.StringPtrInput
	Tags      pulumi.StringMapInput
	// Cluster management task.
	TaskStatus pulumi.StringPtrInput
	// The updated time of the cluster.
	Updated pulumi.StringPtrInput
	// Administrator username for logging in to a data warehouse cluster.
	UserName pulumi.StringPtrInput
	// Administrator password for logging in to a data warehouse cluster.
	UserPwd pulumi.StringPtrInput
	// schema: Required
	Version pulumi.StringPtrInput
	Volume  ClusterVolumePtrInput
	// The VPC ID.
	VpcId pulumi.StringPtrInput
}

func (ClusterState) ElementType

func (ClusterState) ElementType() reflect.Type

type ClusterVolume

type ClusterVolume struct {
	// The capacity size, in GB.
	Capacity *string `pulumi:"capacity"`
	// The volume type.
	Type *string `pulumi:"type"`
}

type ClusterVolumeArgs

type ClusterVolumeArgs struct {
	// The capacity size, in GB.
	Capacity pulumi.StringPtrInput `pulumi:"capacity"`
	// The volume type.
	Type pulumi.StringPtrInput `pulumi:"type"`
}

func (ClusterVolumeArgs) ElementType

func (ClusterVolumeArgs) ElementType() reflect.Type

func (ClusterVolumeArgs) ToClusterVolumeOutput

func (i ClusterVolumeArgs) ToClusterVolumeOutput() ClusterVolumeOutput

func (ClusterVolumeArgs) ToClusterVolumeOutputWithContext

func (i ClusterVolumeArgs) ToClusterVolumeOutputWithContext(ctx context.Context) ClusterVolumeOutput

func (ClusterVolumeArgs) ToClusterVolumePtrOutput

func (i ClusterVolumeArgs) ToClusterVolumePtrOutput() ClusterVolumePtrOutput

func (ClusterVolumeArgs) ToClusterVolumePtrOutputWithContext

func (i ClusterVolumeArgs) ToClusterVolumePtrOutputWithContext(ctx context.Context) ClusterVolumePtrOutput

type ClusterVolumeInput

type ClusterVolumeInput interface {
	pulumi.Input

	ToClusterVolumeOutput() ClusterVolumeOutput
	ToClusterVolumeOutputWithContext(context.Context) ClusterVolumeOutput
}

ClusterVolumeInput is an input type that accepts ClusterVolumeArgs and ClusterVolumeOutput values. You can construct a concrete instance of `ClusterVolumeInput` via:

ClusterVolumeArgs{...}

type ClusterVolumeOutput

type ClusterVolumeOutput struct{ *pulumi.OutputState }

func (ClusterVolumeOutput) Capacity

The capacity size, in GB.

func (ClusterVolumeOutput) ElementType

func (ClusterVolumeOutput) ElementType() reflect.Type

func (ClusterVolumeOutput) ToClusterVolumeOutput

func (o ClusterVolumeOutput) ToClusterVolumeOutput() ClusterVolumeOutput

func (ClusterVolumeOutput) ToClusterVolumeOutputWithContext

func (o ClusterVolumeOutput) ToClusterVolumeOutputWithContext(ctx context.Context) ClusterVolumeOutput

func (ClusterVolumeOutput) ToClusterVolumePtrOutput

func (o ClusterVolumeOutput) ToClusterVolumePtrOutput() ClusterVolumePtrOutput

func (ClusterVolumeOutput) ToClusterVolumePtrOutputWithContext

func (o ClusterVolumeOutput) ToClusterVolumePtrOutputWithContext(ctx context.Context) ClusterVolumePtrOutput

func (ClusterVolumeOutput) Type

The volume type.

type ClusterVolumePtrInput

type ClusterVolumePtrInput interface {
	pulumi.Input

	ToClusterVolumePtrOutput() ClusterVolumePtrOutput
	ToClusterVolumePtrOutputWithContext(context.Context) ClusterVolumePtrOutput
}

ClusterVolumePtrInput is an input type that accepts ClusterVolumeArgs, ClusterVolumePtr and ClusterVolumePtrOutput values. You can construct a concrete instance of `ClusterVolumePtrInput` via:

        ClusterVolumeArgs{...}

or:

        nil

type ClusterVolumePtrOutput

type ClusterVolumePtrOutput struct{ *pulumi.OutputState }

func (ClusterVolumePtrOutput) Capacity

The capacity size, in GB.

func (ClusterVolumePtrOutput) Elem

func (ClusterVolumePtrOutput) ElementType

func (ClusterVolumePtrOutput) ElementType() reflect.Type

func (ClusterVolumePtrOutput) ToClusterVolumePtrOutput

func (o ClusterVolumePtrOutput) ToClusterVolumePtrOutput() ClusterVolumePtrOutput

func (ClusterVolumePtrOutput) ToClusterVolumePtrOutputWithContext

func (o ClusterVolumePtrOutput) ToClusterVolumePtrOutputWithContext(ctx context.Context) ClusterVolumePtrOutput

func (ClusterVolumePtrOutput) Type

The volume type.

type GetFlaovrsArgs

type GetFlaovrsArgs struct {
	AvailabilityZone *string `pulumi:"availabilityZone"`
	DatastoreType    *string `pulumi:"datastoreType"`
	Memory           *int    `pulumi:"memory"`
	Region           *string `pulumi:"region"`
	Vcpus            *int    `pulumi:"vcpus"`
}

A collection of arguments for invoking getFlaovrs.

type GetFlaovrsFlavor

type GetFlaovrsFlavor struct {
	// The list of availability zones.
	AvailabilityZones []string `pulumi:"availabilityZones"`
	// The type of datastore.
	DatastoreType string `pulumi:"datastoreType"`
	// The version of datastore.
	DatastoreVersion string `pulumi:"datastoreVersion"`
	// The typical specification, If the volume specification is elastic.
	ElasticVolumeSpecs []GetFlaovrsFlavorElasticVolumeSpec `pulumi:"elasticVolumeSpecs"`
	// The name of the dws node flavor.
	FlavorId string `pulumi:"flavorId"`
	// The ram of the dws node flavor in GB.
	Memory int `pulumi:"memory"`
	// The default disk size in GB.
	Size int `pulumi:"size"`
	// The vcpus of the dws node flavor.
	Vcpus int `pulumi:"vcpus"`
	// Disk type.
	Volumetype string `pulumi:"volumetype"`
}

type GetFlaovrsFlavorArgs

type GetFlaovrsFlavorArgs struct {
	// The list of availability zones.
	AvailabilityZones pulumi.StringArrayInput `pulumi:"availabilityZones"`
	// The type of datastore.
	DatastoreType pulumi.StringInput `pulumi:"datastoreType"`
	// The version of datastore.
	DatastoreVersion pulumi.StringInput `pulumi:"datastoreVersion"`
	// The typical specification, If the volume specification is elastic.
	ElasticVolumeSpecs GetFlaovrsFlavorElasticVolumeSpecArrayInput `pulumi:"elasticVolumeSpecs"`
	// The name of the dws node flavor.
	FlavorId pulumi.StringInput `pulumi:"flavorId"`
	// The ram of the dws node flavor in GB.
	Memory pulumi.IntInput `pulumi:"memory"`
	// The default disk size in GB.
	Size pulumi.IntInput `pulumi:"size"`
	// The vcpus of the dws node flavor.
	Vcpus pulumi.IntInput `pulumi:"vcpus"`
	// Disk type.
	Volumetype pulumi.StringInput `pulumi:"volumetype"`
}

func (GetFlaovrsFlavorArgs) ElementType

func (GetFlaovrsFlavorArgs) ElementType() reflect.Type

func (GetFlaovrsFlavorArgs) ToGetFlaovrsFlavorOutput

func (i GetFlaovrsFlavorArgs) ToGetFlaovrsFlavorOutput() GetFlaovrsFlavorOutput

func (GetFlaovrsFlavorArgs) ToGetFlaovrsFlavorOutputWithContext

func (i GetFlaovrsFlavorArgs) ToGetFlaovrsFlavorOutputWithContext(ctx context.Context) GetFlaovrsFlavorOutput

type GetFlaovrsFlavorArray

type GetFlaovrsFlavorArray []GetFlaovrsFlavorInput

func (GetFlaovrsFlavorArray) ElementType

func (GetFlaovrsFlavorArray) ElementType() reflect.Type

func (GetFlaovrsFlavorArray) ToGetFlaovrsFlavorArrayOutput

func (i GetFlaovrsFlavorArray) ToGetFlaovrsFlavorArrayOutput() GetFlaovrsFlavorArrayOutput

func (GetFlaovrsFlavorArray) ToGetFlaovrsFlavorArrayOutputWithContext

func (i GetFlaovrsFlavorArray) ToGetFlaovrsFlavorArrayOutputWithContext(ctx context.Context) GetFlaovrsFlavorArrayOutput

type GetFlaovrsFlavorArrayInput

type GetFlaovrsFlavorArrayInput interface {
	pulumi.Input

	ToGetFlaovrsFlavorArrayOutput() GetFlaovrsFlavorArrayOutput
	ToGetFlaovrsFlavorArrayOutputWithContext(context.Context) GetFlaovrsFlavorArrayOutput
}

GetFlaovrsFlavorArrayInput is an input type that accepts GetFlaovrsFlavorArray and GetFlaovrsFlavorArrayOutput values. You can construct a concrete instance of `GetFlaovrsFlavorArrayInput` via:

GetFlaovrsFlavorArray{ GetFlaovrsFlavorArgs{...} }

type GetFlaovrsFlavorArrayOutput

type GetFlaovrsFlavorArrayOutput struct{ *pulumi.OutputState }

func (GetFlaovrsFlavorArrayOutput) ElementType

func (GetFlaovrsFlavorArrayOutput) Index

func (GetFlaovrsFlavorArrayOutput) ToGetFlaovrsFlavorArrayOutput

func (o GetFlaovrsFlavorArrayOutput) ToGetFlaovrsFlavorArrayOutput() GetFlaovrsFlavorArrayOutput

func (GetFlaovrsFlavorArrayOutput) ToGetFlaovrsFlavorArrayOutputWithContext

func (o GetFlaovrsFlavorArrayOutput) ToGetFlaovrsFlavorArrayOutputWithContext(ctx context.Context) GetFlaovrsFlavorArrayOutput

type GetFlaovrsFlavorElasticVolumeSpec

type GetFlaovrsFlavorElasticVolumeSpec struct {
	// Maximum disk size.
	MaxSize int `pulumi:"maxSize"`
	// Minimum disk size.
	MinSize int `pulumi:"minSize"`
	// Disk size increment step.
	Step int `pulumi:"step"`
}

type GetFlaovrsFlavorElasticVolumeSpecArgs

type GetFlaovrsFlavorElasticVolumeSpecArgs struct {
	// Maximum disk size.
	MaxSize pulumi.IntInput `pulumi:"maxSize"`
	// Minimum disk size.
	MinSize pulumi.IntInput `pulumi:"minSize"`
	// Disk size increment step.
	Step pulumi.IntInput `pulumi:"step"`
}

func (GetFlaovrsFlavorElasticVolumeSpecArgs) ElementType

func (GetFlaovrsFlavorElasticVolumeSpecArgs) ToGetFlaovrsFlavorElasticVolumeSpecOutput

func (i GetFlaovrsFlavorElasticVolumeSpecArgs) ToGetFlaovrsFlavorElasticVolumeSpecOutput() GetFlaovrsFlavorElasticVolumeSpecOutput

func (GetFlaovrsFlavorElasticVolumeSpecArgs) ToGetFlaovrsFlavorElasticVolumeSpecOutputWithContext

func (i GetFlaovrsFlavorElasticVolumeSpecArgs) ToGetFlaovrsFlavorElasticVolumeSpecOutputWithContext(ctx context.Context) GetFlaovrsFlavorElasticVolumeSpecOutput

type GetFlaovrsFlavorElasticVolumeSpecArray

type GetFlaovrsFlavorElasticVolumeSpecArray []GetFlaovrsFlavorElasticVolumeSpecInput

func (GetFlaovrsFlavorElasticVolumeSpecArray) ElementType

func (GetFlaovrsFlavorElasticVolumeSpecArray) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutput

func (i GetFlaovrsFlavorElasticVolumeSpecArray) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutput() GetFlaovrsFlavorElasticVolumeSpecArrayOutput

func (GetFlaovrsFlavorElasticVolumeSpecArray) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutputWithContext

func (i GetFlaovrsFlavorElasticVolumeSpecArray) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutputWithContext(ctx context.Context) GetFlaovrsFlavorElasticVolumeSpecArrayOutput

type GetFlaovrsFlavorElasticVolumeSpecArrayInput

type GetFlaovrsFlavorElasticVolumeSpecArrayInput interface {
	pulumi.Input

	ToGetFlaovrsFlavorElasticVolumeSpecArrayOutput() GetFlaovrsFlavorElasticVolumeSpecArrayOutput
	ToGetFlaovrsFlavorElasticVolumeSpecArrayOutputWithContext(context.Context) GetFlaovrsFlavorElasticVolumeSpecArrayOutput
}

GetFlaovrsFlavorElasticVolumeSpecArrayInput is an input type that accepts GetFlaovrsFlavorElasticVolumeSpecArray and GetFlaovrsFlavorElasticVolumeSpecArrayOutput values. You can construct a concrete instance of `GetFlaovrsFlavorElasticVolumeSpecArrayInput` via:

GetFlaovrsFlavorElasticVolumeSpecArray{ GetFlaovrsFlavorElasticVolumeSpecArgs{...} }

type GetFlaovrsFlavorElasticVolumeSpecArrayOutput

type GetFlaovrsFlavorElasticVolumeSpecArrayOutput struct{ *pulumi.OutputState }

func (GetFlaovrsFlavorElasticVolumeSpecArrayOutput) ElementType

func (GetFlaovrsFlavorElasticVolumeSpecArrayOutput) Index

func (GetFlaovrsFlavorElasticVolumeSpecArrayOutput) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutput

func (o GetFlaovrsFlavorElasticVolumeSpecArrayOutput) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutput() GetFlaovrsFlavorElasticVolumeSpecArrayOutput

func (GetFlaovrsFlavorElasticVolumeSpecArrayOutput) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutputWithContext

func (o GetFlaovrsFlavorElasticVolumeSpecArrayOutput) ToGetFlaovrsFlavorElasticVolumeSpecArrayOutputWithContext(ctx context.Context) GetFlaovrsFlavorElasticVolumeSpecArrayOutput

type GetFlaovrsFlavorElasticVolumeSpecInput

type GetFlaovrsFlavorElasticVolumeSpecInput interface {
	pulumi.Input

	ToGetFlaovrsFlavorElasticVolumeSpecOutput() GetFlaovrsFlavorElasticVolumeSpecOutput
	ToGetFlaovrsFlavorElasticVolumeSpecOutputWithContext(context.Context) GetFlaovrsFlavorElasticVolumeSpecOutput
}

GetFlaovrsFlavorElasticVolumeSpecInput is an input type that accepts GetFlaovrsFlavorElasticVolumeSpecArgs and GetFlaovrsFlavorElasticVolumeSpecOutput values. You can construct a concrete instance of `GetFlaovrsFlavorElasticVolumeSpecInput` via:

GetFlaovrsFlavorElasticVolumeSpecArgs{...}

type GetFlaovrsFlavorElasticVolumeSpecOutput

type GetFlaovrsFlavorElasticVolumeSpecOutput struct{ *pulumi.OutputState }

func (GetFlaovrsFlavorElasticVolumeSpecOutput) ElementType

func (GetFlaovrsFlavorElasticVolumeSpecOutput) MaxSize

Maximum disk size.

func (GetFlaovrsFlavorElasticVolumeSpecOutput) MinSize

Minimum disk size.

func (GetFlaovrsFlavorElasticVolumeSpecOutput) Step

Disk size increment step.

func (GetFlaovrsFlavorElasticVolumeSpecOutput) ToGetFlaovrsFlavorElasticVolumeSpecOutput

func (o GetFlaovrsFlavorElasticVolumeSpecOutput) ToGetFlaovrsFlavorElasticVolumeSpecOutput() GetFlaovrsFlavorElasticVolumeSpecOutput

func (GetFlaovrsFlavorElasticVolumeSpecOutput) ToGetFlaovrsFlavorElasticVolumeSpecOutputWithContext

func (o GetFlaovrsFlavorElasticVolumeSpecOutput) ToGetFlaovrsFlavorElasticVolumeSpecOutputWithContext(ctx context.Context) GetFlaovrsFlavorElasticVolumeSpecOutput

type GetFlaovrsFlavorInput

type GetFlaovrsFlavorInput interface {
	pulumi.Input

	ToGetFlaovrsFlavorOutput() GetFlaovrsFlavorOutput
	ToGetFlaovrsFlavorOutputWithContext(context.Context) GetFlaovrsFlavorOutput
}

GetFlaovrsFlavorInput is an input type that accepts GetFlaovrsFlavorArgs and GetFlaovrsFlavorOutput values. You can construct a concrete instance of `GetFlaovrsFlavorInput` via:

GetFlaovrsFlavorArgs{...}

type GetFlaovrsFlavorOutput

type GetFlaovrsFlavorOutput struct{ *pulumi.OutputState }

func (GetFlaovrsFlavorOutput) AvailabilityZones

func (o GetFlaovrsFlavorOutput) AvailabilityZones() pulumi.StringArrayOutput

The list of availability zones.

func (GetFlaovrsFlavorOutput) DatastoreType

func (o GetFlaovrsFlavorOutput) DatastoreType() pulumi.StringOutput

The type of datastore.

func (GetFlaovrsFlavorOutput) DatastoreVersion

func (o GetFlaovrsFlavorOutput) DatastoreVersion() pulumi.StringOutput

The version of datastore.

func (GetFlaovrsFlavorOutput) ElasticVolumeSpecs

The typical specification, If the volume specification is elastic.

func (GetFlaovrsFlavorOutput) ElementType

func (GetFlaovrsFlavorOutput) ElementType() reflect.Type

func (GetFlaovrsFlavorOutput) FlavorId

The name of the dws node flavor.

func (GetFlaovrsFlavorOutput) Memory

The ram of the dws node flavor in GB.

func (GetFlaovrsFlavorOutput) Size

The default disk size in GB.

func (GetFlaovrsFlavorOutput) ToGetFlaovrsFlavorOutput

func (o GetFlaovrsFlavorOutput) ToGetFlaovrsFlavorOutput() GetFlaovrsFlavorOutput

func (GetFlaovrsFlavorOutput) ToGetFlaovrsFlavorOutputWithContext

func (o GetFlaovrsFlavorOutput) ToGetFlaovrsFlavorOutputWithContext(ctx context.Context) GetFlaovrsFlavorOutput

func (GetFlaovrsFlavorOutput) Vcpus

The vcpus of the dws node flavor.

func (GetFlaovrsFlavorOutput) Volumetype

Disk type.

type GetFlaovrsOutputArgs

type GetFlaovrsOutputArgs struct {
	AvailabilityZone pulumi.StringPtrInput `pulumi:"availabilityZone"`
	DatastoreType    pulumi.StringPtrInput `pulumi:"datastoreType"`
	Memory           pulumi.IntPtrInput    `pulumi:"memory"`
	Region           pulumi.StringPtrInput `pulumi:"region"`
	Vcpus            pulumi.IntPtrInput    `pulumi:"vcpus"`
}

A collection of arguments for invoking getFlaovrs.

func (GetFlaovrsOutputArgs) ElementType

func (GetFlaovrsOutputArgs) ElementType() reflect.Type

type GetFlaovrsResult

type GetFlaovrsResult struct {
	AvailabilityZone *string            `pulumi:"availabilityZone"`
	DatastoreType    *string            `pulumi:"datastoreType"`
	Flavors          []GetFlaovrsFlavor `pulumi:"flavors"`
	// The provider-assigned unique ID for this managed resource.
	Id     string `pulumi:"id"`
	Memory *int   `pulumi:"memory"`
	Region string `pulumi:"region"`
	Vcpus  *int   `pulumi:"vcpus"`
}

A collection of values returned by getFlaovrs.

func GetFlaovrs

func GetFlaovrs(ctx *pulumi.Context, args *GetFlaovrsArgs, opts ...pulumi.InvokeOption) (*GetFlaovrsResult, error)

type GetFlaovrsResultOutput

type GetFlaovrsResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getFlaovrs.

func (GetFlaovrsResultOutput) AvailabilityZone

func (o GetFlaovrsResultOutput) AvailabilityZone() pulumi.StringPtrOutput

func (GetFlaovrsResultOutput) DatastoreType

func (o GetFlaovrsResultOutput) DatastoreType() pulumi.StringPtrOutput

func (GetFlaovrsResultOutput) ElementType

func (GetFlaovrsResultOutput) ElementType() reflect.Type

func (GetFlaovrsResultOutput) Flavors

func (GetFlaovrsResultOutput) Id

The provider-assigned unique ID for this managed resource.

func (GetFlaovrsResultOutput) Memory

func (GetFlaovrsResultOutput) Region

func (GetFlaovrsResultOutput) ToGetFlaovrsResultOutput

func (o GetFlaovrsResultOutput) ToGetFlaovrsResultOutput() GetFlaovrsResultOutput

func (GetFlaovrsResultOutput) ToGetFlaovrsResultOutputWithContext

func (o GetFlaovrsResultOutput) ToGetFlaovrsResultOutputWithContext(ctx context.Context) GetFlaovrsResultOutput

func (GetFlaovrsResultOutput) Vcpus

Jump to